///////////////////////////////////////////////////////////
// GAUGE.CPP: gauge control
///////////////////////////////////////////////////////////
#include <owl\applicat.h>
#include <owl\framewin.h>
#include <owl\gauge.h>
#include <stdio.h>
#include <string.h>
#pragma hdrstop
#include "gauge.rc"

#define ID_GAUGE 100    //gauge ID
#define GMIN 0          //minimum gauge range value
#define GMAX 100        //maximum gauge range value

//////////////////////////////////
// The main window class.
//////////////////////////////////
class TWndw : public TFrameWindow
{
public:
	TWndw(TWindow *parent, const char far *title);
	~TWndw();
protected:
	void SetupWindow();
	void CleanupWindow();
	void EvTimer(UINT);
private:
	TGauge* gauge;
DECLARE_RESPONSE_TABLE(TWndw);
};
DEFINE_RESPONSE_TABLE1(TWndw, TWindow)
	// Place response table entries here.
	EV_WM_TIMER,
END_RESPONSE_TABLE;

///////////////////////////////////////////////////////////
// TWndw::TWndw()
///////////////////////////////////////////////////////////
TWndw::TWndw(TWindow *parent, const char far *title)
	:	TFrameWindow(parent, title)
{
	AssignMenu(MENU_1);
	// Perform object initialization here.

	Attr.X = 50;
	Attr.Y = 50;
	Attr.W = 400;
	Attr.H = 300;

	gauge = new TGauge(this, "0 %%",
		ID_GAUGE, 50, 50, 300, 30, TRUE,  // FALSE for vertical
		2);	//margin
}

///////////////////////////////////////////////////////////
// TWndw::~TWndw()
///////////////////////////////////////////////////////////
TWndw::~TWndw()
{
	// Perform object cleanup here.
}

///////////////////////////////////////////////////////////
// TWndw::SetupWindow()
///////////////////////////////////////////////////////////
void TWndw::SetupWindow()
{
	// Call base class's SetupWindow.
	TFrameWindow::SetupWindow();

	// Perform initialization that requires a
	// valid window handle here.
	SetTimer(1, 100);

	gauge->SetRange(GMIN, GMAX);		//min value, max value
	gauge->SetValue(0);					//initial value
	gauge->SetLed(0);						//smooth bar
}

///////////////////////////////////////////////////////////
// TWndw::CleanupWindow()
///////////////////////////////////////////////////////////
void TWndw::CleanupWindow()
{
	// Perform cleanup that requires a valid
	// window handle here.
	KillTimer(1);
}

void TWndw::EvTimer(UINT)
{
	int v = gauge->GetValue();
	v++;
	if (v > GMAX) {
		v = GMIN;
		MessageBeep(MB_ICONEXCLAMATION);
	}
	gauge->SetValue(v);  // Forces update event for control

	char valueString[15];
	sprintf(valueString, "%d %%%", v);
	gauge->SetCaption(valueString);
//	gauge->SetText(valueString);
}

//////////////////////////////////
// The application class.
//////////////////////////////////
class TApp : public TApplication
{
public:
	TApp(): TApplication() {}
	void InitMainWindow();
};

///////////////////////////////////////////////////////////
// TApp::InitMainWindow()
///////////////////////////////////////////////////////////
void TApp::InitMainWindow()
{
	TFrameWindow *wndw = new TWndw(0, "Gauge Example");
	SetMainWindow(wndw);
//	nCmdShow=SW_HIDE;
}

///////////////////////////////////////////////////////////
// OwlMain()
///////////////////////////////////////////////////////////
int OwlMain(int, char*[])
{
	return TApp().Run();
}

